===============================
RemoteStats - Client
===============================

.. image:: https://img.shields.io/pypi/v/remotestatsclient.svg
        :target: https://pypi.python.org/pypi/remotestatsclient

.. image:: https://img.shields.io/travis/hugombarreto/remotestatsclient.svg
        :target: https://travis-ci.org/hugombarreto/remotestatsclient

.. image:: https://readthedocs.org/projects/remotestatsclient/badge/?version=latest
        :target: https://readthedocs.org/projects/remotestatsclient/?badge=latest
        :alt: Documentation Status


RemoteStats makes possible to inspect realtime information about a remote machine using a browser. This is the client to be installed in such machine.

* Free software: ISC license
* Documentation: https://remotestatsclient.readthedocs.org.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
